@@ -11,6 +11,11 @@ NULL
 .presto.to.R <- as.data.frame(matrix(c(
   'boolean', 'logical',
   'bigint', 'integer',
+  'integer', 'integer',
+  'smallint', 'integer',
+  'tinyint', 'integer',
+  'decimal', 'character',
+  'real', 'numeric',
   'double', 'numeric',
   'varchar', 'character',
   'varbinary', 'raw',
