@@ -5,14 +5,18 @@
 # LICENSE file in the root directory of this source tree. An additional grant
 # of patent rights can be found in the PATENTS file in the same directory.
 
+#' @include dbplyr_compatible.R
+NULL
+
 #' S3 implementation of \code{sql_translate_env} for Presto.
 #'
 #' @rdname dplyr_function_implementations
 #' @keywords internal
 #' @export
 db_query_fields.PrestoConnection <- function(con, sql, ...) {
-  fields <- dplyr::build_sql(
-    "SELECT * FROM ", sql, " LIMIT 0",
+  build_sql <- dbplyr_compatible('build_sql')
+  fields <- build_sql(
+    "SELECT * FROM ", dplyr::sql_subquery(con, sql), " LIMIT 0",
     con = con
   )
   result <- dbSendQuery(con, fields)
