@@ -5,25 +5,16 @@
 # LICENSE file in the root directory of this source tree. An additional grant
 # of patent rights can be found in the PATENTS file in the same directory.
 
-#' S3 implementation of \code{\link[dplyr]{src_desc}} for Presto.
+#' @include description_from_info.R
+NULL
+
+
+#' S3 implementation of \code{src_desc} for Presto.
 #'
 #' @rdname dplyr_function_implementations
 #' @keywords internal
 #' @export
 src_desc.src_presto <- function(x) {
   info <- x[['info']]
-  return(paste0(
-    'presto ',
-    ' [',
-    info[['schema']],
-    ':',
-    info[['catalog']],
-    ' | ',
-    info[['user']],
-    '@',
-    info[['host']],
-    ':',
-    info[['port']],
-    ']'
-  ))
+  return(.description_from_info(info))
 }
